@@ -1,4 +1,4 @@
-//@line 36 "/builds/slave/192-lnx64-xr/build/toolkit/components/apppicker/content/appPicker.js"
+//@line 36 "/builds/slave/rel-rel-xr-lnx64-bld/build/toolkit/components/apppicker/content/appPicker.js"
 
 function AppPicker() {};
 
@@ -55,20 +55,7 @@ AppPicker.prototype =
         // Grab a list of nsILocalHandlerApp application helpers to list
         var fileList = mimeInfo.possibleLocalHandlers;
 
-        /*
-          <richlistitem id="app-picker-item" value=nsfileobject>
-            <hbox align="center">
-              <image id="app-picker-item-image" src=""/>
-              <vbox>
-                <hbox align="center">
-                  <listcell id="app-picker-item-cell" label="Outlook"/>
-                </hbox>
-              </vbox>
-            </hbox>
-          </richlistitem>
-        */
-
-        var list = document.getElementById("app-picker-list");
+        var list = document.getElementById("app-picker-listbox");
 
         var primaryCount = 0;
         
@@ -87,32 +74,11 @@ AppPicker.prototype =
             continue;
           }
 
-          var item = document.createElement("richlistitem");
-          item.setAttribute("id", "app-picker-item");
-          item.value = file;
-          item.label = this.getFileDisplayName(file.executable);
-          item.setAttribute("ondblclick", "g_dialog.appDoubleClick();");
-
-          var hbox1 = document.createElement("hbox");
-          hbox1.setAttribute("align", "center");
-
-          var image = document.createElement("image");
-          image.setAttribute("id", "app-picker-item-image");
-          image.setAttribute("src", this.getFileIconURL(file.executable));
-
-          var vbox1 = document.createElement("vbox");
-          var hbox2 = document.createElement("hbox");
-          hbox2.setAttribute("align", "center");
-
-          var cell = document.createElement("listcell");
-          cell.setAttribute("id", "app-picker-item-cell");
-          cell.setAttribute("label", this.getFileDisplayName(file.executable));
-
-          hbox2.appendChild(cell);
-          vbox1.appendChild(hbox2);
-          hbox1.appendChild(image);
-          hbox1.appendChild(vbox1);
-          item.appendChild(hbox1);
+          var item = document.createElement("listitem");
+          item.className = "listitem-iconic";
+          item.handlerApp = file;
+          item.setAttribute("label", this.getFileDisplayName(file.executable));
+          item.setAttribute("image", this.getFileIconURL(file.executable));
           list.appendChild(item);
 
           primaryCount++;
@@ -147,7 +113,7 @@ AppPicker.prototype =
     * Retrieve the pretty description from the file
     */ 
     getFileDisplayName: function getFileDisplayName(file) {
-//@line 202 "/builds/slave/192-lnx64-xr/build/toolkit/components/apppicker/content/appPicker.js"
+//@line 164 "/builds/slave/rel-rel-xr-lnx64-bld/build/toolkit/components/apppicker/content/appPicker.js"
       return file.leafName;
     },
 
@@ -155,7 +121,7 @@ AppPicker.prototype =
     * Double click accepts an app
     */
     appDoubleClick: function appDoubleClick() {
-      var list = document.getElementById("app-picker-list");
+      var list = document.getElementById("app-picker-listbox");
       var selItem = list.selectedItem;
 
       if (!selItem) {
@@ -163,7 +129,7 @@ AppPicker.prototype =
           return true;
       }
 
-      this._incomingParams.handlerApp = selItem.value;
+      this._incomingParams.handlerApp = selItem.handlerApp;
       window.close();
 
       return true;
@@ -172,14 +138,14 @@ AppPicker.prototype =
     appPickerOK: function appPickerOK() {
       if (this._incomingParams.handlerApp) return true;
 
-      var list = document.getElementById("app-picker-list");
+      var list = document.getElementById("app-picker-listbox");
       var selItem = list.selectedItem;
 
       if (!selItem) {
         this._incomingParams.handlerApp = null;
         return true;
       }
-      this._incomingParams.handlerApp = selItem.value;
+      this._incomingParams.handlerApp = selItem.handlerApp;
 
       return true;
     },
@@ -203,9 +169,9 @@ AppPicker.prototype =
       var fileLoc = Components.classes["@mozilla.org/file/directory_service;1"]
                             .getService(Components.interfaces.nsIProperties);
       var startLocation;
-//@line 263 "/builds/slave/192-lnx64-xr/build/toolkit/components/apppicker/content/appPicker.js"
+//@line 225 "/builds/slave/rel-rel-xr-lnx64-bld/build/toolkit/components/apppicker/content/appPicker.js"
     startLocation = "Home";
-//@line 266 "/builds/slave/192-lnx64-xr/build/toolkit/components/apppicker/content/appPicker.js"
+//@line 228 "/builds/slave/rel-rel-xr-lnx64-bld/build/toolkit/components/apppicker/content/appPicker.js"
       fp.displayDirectory = 
         fileLoc.get(startLocation, Components.interfaces.nsILocalFile);
       
