@@ -27,14 +27,14 @@ pref("security.ssl3.rsa_1024_des_cbc_sha", false);
 pref("security.ssl3.rsa_rc4_40_md5", false);
 pref("security.ssl3.rsa_rc2_40_md5", false);
 // Camellia is broken on Windows CE for now, see bug 508113
-//@line 31 "/builds/slave/2.0-lnx64-xr/build/netwerk/base/public/security-prefs.js"
+//@line 31 "/builds/slave/beta-lnx64-xr/build/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_dss_camellia_256_sha", true);
 pref("security.ssl3.rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_rsa_camellia_128_sha", true);
 pref("security.ssl3.dhe_dss_camellia_128_sha", true);
 pref("security.ssl3.rsa_camellia_128_sha", true);
-//@line 38 "/builds/slave/2.0-lnx64-xr/build/netwerk/base/public/security-prefs.js"
+//@line 38 "/builds/slave/beta-lnx64-xr/build/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_aes_256_sha", true);
 pref("security.ssl3.dhe_dss_aes_256_sha", true);
 pref("security.ssl3.rsa_aes_256_sha", true);
@@ -148,9 +148,9 @@ pref("browser.cache.disk.smart_size.first_run", true);
 // Does the user want smart-sizing?
 pref("browser.cache.disk.smart_size.enabled", true);
 // Size explicitly set by the user. Used when smart_size.enabled == false
-//@line 69 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 69 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         256000);
-//@line 73 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 73 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -159,7 +159,7 @@ pref("browser.cache.disk_cache_ssl",        true);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 82 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 82 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -170,7 +170,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 98 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 98 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether or not indexedDB is enabled.
 pref("dom.indexedDB.enabled", true);
@@ -245,13 +245,13 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 512000);
 
-//@line 176 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 176 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 179 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 179 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 182 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 182 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.webm.enabled", true);
-//@line 184 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 184 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -265,20 +265,24 @@ pref("gfx.color_management.rendering_intent", 0);
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.fallback_delay", 3000);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 200 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 200 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 202 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 202 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-pref("gfx.font_rendering.harfbuzz.level", 2);
+// see gfx/thebes/gfxUnicodeProperties.h for definitions of script bits
+//@line 208 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+// use harfbuzz for default (0x01) + arabic (0x02)
+pref("gfx.font_rendering.harfbuzz.scripts", 3);
+//@line 211 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 211 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 218 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 218 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 225 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -295,7 +299,7 @@ pref("accessibility.win32.force_disabled", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 238 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 245 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -635,12 +639,14 @@ pref("dom.storage.default_quota",      5120);
 pref("dom.send_after_paint_to_content", false);
 
 // Timeout clamp in ms for timeouts we clamp
-pref("dom.min_timeout_value", 10);
+pref("dom.min_timeout_value", 4);
+// And for background windows
+pref("dom.min_background_timeout_value", 1000);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 581 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 590 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 583 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 592 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -655,7 +661,7 @@ pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
 pref("javascript.options.strict",           false);
-//@line 600 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 609 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("javascript.options.relimit",          true);
 pref("javascript.options.tracejit.content",  true);
 pref("javascript.options.tracejit.chrome",   true);
@@ -701,7 +707,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 648 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 657 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -997,7 +1003,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 949 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 958 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1064,10 +1070,10 @@ pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/in
 pref("intl.charsetmenu.browser.static",     "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.more1",      "ISO-8859-1, ISO-8859-15, IBM850, x-mac-roman, windows-1252, ISO-8859-14, ISO-8859-7, x-mac-greek, windows-1253, x-mac-icelandic, ISO-8859-10, ISO-8859-3");
 pref("intl.charsetmenu.browser.more2",      "ISO-8859-4, ISO-8859-13, windows-1257, IBM852, ISO-8859-2, x-mac-ce, windows-1250, x-mac-croatian, IBM855, ISO-8859-5, ISO-IR-111, KOI8-R, x-mac-cyrillic, windows-1251, IBM866, KOI8-U, x-mac-ukrainian, ISO-8859-16, x-mac-romanian");
-pref("intl.charsetmenu.browser.more3",      "GB2312, x-gbk, gb18030, HZ-GB-2312, ISO-2022-CN, Big5, Big5-HKSCS, x-euc-tw, EUC-JP, ISO-2022-JP, Shift_JIS, EUC-KR, x-windows-949, x-johab, ISO-2022-KR");
+pref("intl.charsetmenu.browser.more3",      "GB2312, gbk, gb18030, HZ-GB-2312, ISO-2022-CN, Big5, Big5-HKSCS, x-euc-tw, EUC-JP, ISO-2022-JP, Shift_JIS, EUC-KR, x-windows-949, x-johab, ISO-2022-KR");
 pref("intl.charsetmenu.browser.more4",      "armscii-8, GEOSTD8, TIS-620, ISO-8859-11, windows-874, IBM857, ISO-8859-9, x-mac-turkish, windows-1254, x-viet-tcvn5712, VISCII, x-viet-vps, windows-1258, x-mac-devanagari, x-mac-gujarati, x-mac-gurmukhi");
 pref("intl.charsetmenu.browser.more5",      "ISO-8859-6, windows-1256, IBM864, ISO-8859-8-I, windows-1255, ISO-8859-8, IBM862");
-pref("intl.charsetmenu.browser.unicode",    "UTF-8, UTF-16LE, UTF-16BE, UTF-32, UTF-32LE, UTF-32BE");
+pref("intl.charsetmenu.browser.unicode",    "UTF-8, UTF-16LE, UTF-16BE");
 pref("intl.charsetmenu.mailedit",           "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.cache",      "");
 pref("intl.charsetmenu.mailview.cache",     "");
@@ -1386,24 +1392,25 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1338 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1347 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1349 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1358 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1357 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1366 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // Linux plugins using Xt instead of Xembed don't work out-of-process yet.
 pref("dom.ipc.plugins.enabled.libvlcplugin.so", false);
 pref("dom.ipc.plugins.enabled.nppdf.so", false);
-//@line 1363 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+pref("dom.ipc.plugins.enabled.602plugin.so", false);
+//@line 1373 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("svg.smil.enabled", true);
 
@@ -1440,17 +1447,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1829 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1833 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2257 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2261 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2457 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2461 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2553 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2730 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2822 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
-
-//@line 2826 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2734 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.protocol-handler.warn-external.file", false);
 pref("browser.drag_out_of_frame_style", 1);
@@ -1718,13 +1723,11 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 3097 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3005 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3123 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3025 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3143 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
-
-//@line 3151 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3033 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1798,9 +1801,9 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3230 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3112 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3235 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3117 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
 pref("layers.acceleration.disabled", false);
@@ -1808,7 +1811,7 @@ pref("layers.acceleration.disabled", false);
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3254 "/builds/slave/2.0-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3136 "/builds/slave/beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
