@@ -1,10 +1,8 @@
-//@line 37 "/builds/slave/192-lnx64-xr/build/toolkit/mozapps/xpinstall/content/xpinstallConfirm.js"
+//@line 37 "/builds/slave/beta-lnx64-xr/build/toolkit/mozapps/xpinstall/content/xpinstallConfirm.js"
 
-var XPInstallConfirm = 
-{ 
-  _param: null
-};
+var args
 
+var XPInstallConfirm = {};
 
 XPInstallConfirm.init = function ()
 {
@@ -14,13 +12,9 @@ XPInstallConfirm.init = function ()
   var _timeout;
 
   var bundle = document.getElementById("xpinstallConfirmStrings");
-  
-  this._param = window.arguments[0].QueryInterface(Components.interfaces.nsIDialogParamBlock);
-  if (!this._param)
-    close();
-  
-  this._param.SetInt(0, 1); // The default return value is "Cancel"
-  
+
+  args = window.arguments[0].wrappedJSObject;
+
   var _installCountdownLength = 5;
   try {
     var prefs = Components.classes["@mozilla.org/preferences-service;1"]
@@ -31,29 +25,31 @@ XPInstallConfirm.init = function ()
   
   var itemList = document.getElementById("itemList");
   
-  var numItemsToInstall = this._param.GetInt(1);
+  var numItemsToInstall = args.installs.length;
   for (var i = 0; i < numItemsToInstall; ++i) {
     var installItem = document.createElement("installitem");
     itemList.appendChild(installItem);
 
-    installItem.name = this._param.GetString(i);
-    installItem.url = this._param.GetString(++i);
-    var icon = this._param.GetString(++i);
-    if (icon != "")
+    installItem.name = args.installs[i].addon.name;
+    installItem.url = args.installs[i].sourceURI.spec;
+    var icon = args.installs[i].iconURL;
+    if (icon)
       installItem.icon = icon;
-    var cert = this._param.GetString(++i);
-    if (cert)
-      installItem.cert = bundle.getFormattedString("signed", [cert]);
-    else
+    var type = args.installs[i].type;
+    if (type)
+      installItem.type = type;
+    if (args.installs[i].certName) {
+      installItem.cert = bundle.getFormattedString("signed", [args.installs[i].certName]);
+    }
+    else {
       installItem.cert = bundle.getString("unverified");
-    installItem.signed = cert ? "true" : "false";
+    }
+    installItem.signed = args.installs[i].certName ? "true" : "false";
   }
   
   var introString = bundle.getString("itemWarnIntroSingle");
   if (numItemsToInstall > 4)
-    introString = bundle.getFormattedString("itemWarnIntroMultiple", [numItemsToInstall / 4]);
-  if (this._param.objects && this._param.objects.length)
-    introString = this._param.objects.queryElementAt(0, Components.interfaces.nsISupportsString).data;
+    introString = bundle.getFormattedString("itemWarnIntroMultiple", [numItemsToInstall]);
   var textNode = document.createTextNode(introString);
   var introNode = document.getElementById("itemWarningIntro");
   while (introNode.hasChildNodes())
@@ -138,12 +134,16 @@ XPInstallConfirm.init = function ()
 
 XPInstallConfirm.onOK = function ()
 {
-  this._param.SetInt(0, 0);
+  args.installs.forEach(function(install) {
+    install.install();
+  });
   return true;
 }
 
 XPInstallConfirm.onCancel = function ()
 {
-  this._param.SetInt(0, 1);
+  args.installs.forEach(function(install) {
+    install.cancel();
+  });
   return true;
 }
